@@ -52,9 +52,6 @@ class Job(object):
         token = self.token
         response = self.api.request(
             endpoint="/jobs/%s" % token,
-            json={
-                "token": token,
-            },
         )
         json = response.json()
         self._data.update(json)
